import type {SidebarsConfig} from '@docusaurus/plugin-content-docs';

// This runs in Node.js - Don't use client-side code here (browser APIs, JSX...)

/**
 * Creating a sidebar enables you to:
 - create an ordered group of docs
 - render a sidebar for each doc of that group
 - provide next/previous navigation

 The sidebars can be generated from the filesystem, or explicitly defined here.

 Create as many sidebars as you want.
 */
const sidebars: SidebarsConfig = {
  tutorialSidebar: [
    'intro',
    {
      type: 'category',
      label: 'Getting Started',
      items: [
        'getting-started/installation',
        'getting-started/quickstart',
      ],
    },
    {
      type: 'category',
      label: 'User Guide',
      items: [
        'user-guide/overview',
        'user-guide/python-api',
        'user-guide/examples',
        'user-guide/character-mappings',
      ],
    },
    {
      type: 'category',
      label: 'Architecture',
      items: [
        'architecture/pipeline',
        'architecture/icr',
        'architecture/linguistic-modules',
      ],
    },
    {
      type: 'category',
      label: 'Development',
      items: [
        'development/contributing',
        'development/building',
        'development/testing',
      ],
    },
    'changelog',
  ],
  apiSidebar: [
    'api/python',
  ],
};

export default sidebars;
